@@ -51,7 +51,7 @@ wrap <- function (x, map = list(NA), sep = ".") {
         map <- lapply(map, FUN = function(ii) match(ii, perm))
     }
     dim <- dim(x)
-    dim2 <- lapply(map, FUN = function(ii) prod(dim[ii]))
+    dim2 <- sapply(map, FUN = function(ii) prod(dim[ii]))
     dimnames <- dimnames(x)
     
     tmp_dn<-function(map,dimnames) {
